==> aws-java-sdk-kms-1.10.65-sources.jar: com/amazonaws/services/kms/model/transform/ListKeyPoliciesRequestMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.kms.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import static com.amazonaws.util.StringUtils.COMMA_SEPARATOR;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.kms.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * ListKeyPoliciesRequest Marshaller
 */
public class ListKeyPoliciesRequestMarshaller implements
        Marshaller<Request<ListKeyPoliciesRequest>, ListKeyPoliciesRequest> {

    public Request<ListKeyPoliciesRequest> marshall(
            ListKeyPoliciesRequest listKeyPoliciesRequest) {

        if (listKeyPoliciesRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        Request<ListKeyPoliciesRequest> request = new DefaultRequest<ListKeyPoliciesRequest>(
                listKeyPoliciesRequest, "AWSKMS");
        request.addHeader("X-Amz-Target", "TrentService.ListKeyPolicies");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final SdkJsonGenerator jsonGenerator = new SdkJsonGenerator();

            jsonGenerator.writeStartObject();

            if (listKeyPoliciesRequest.getKeyId() != null) {
                jsonGenerator.writeFieldName("KeyId").writeValue(
                        listKeyPoliciesRequest.getKeyId());
            }
            if (listKeyPoliciesRequest.getLimit() != null) {
                jsonGenerator.writeFieldName("Limit").writeValue(
                        listKeyPoliciesRequest.getLimit());
            }
            if (listKeyPoliciesRequest.getMarker() != null) {
                jsonGenerator.writeFieldName("Marker").writeValue(
                        listKeyPoliciesRequest.getMarker());
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length",
                    Integer.toString(content.length));
            request.addHeader("Content-Type", "application/x-amz-json-1.1");
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}

==> aws-java-sdk-kms-1.10.77-sources.jar: com/amazonaws/services/kms/model/transform/ListKeyPoliciesRequestMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.kms.model.transform;

import java.io.ByteArrayInputStream;
import java.util.Collections;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.kms.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * ListKeyPoliciesRequest Marshaller
 */
public class ListKeyPoliciesRequestMarshaller implements
        Marshaller<Request<ListKeyPoliciesRequest>, ListKeyPoliciesRequest> {

    public Request<ListKeyPoliciesRequest> marshall(
            ListKeyPoliciesRequest listKeyPoliciesRequest) {

        if (listKeyPoliciesRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        Request<ListKeyPoliciesRequest> request = new DefaultRequest<ListKeyPoliciesRequest>(
                listKeyPoliciesRequest, "AWSKMS");
        request.addHeader("X-Amz-Target", "TrentService.ListKeyPolicies");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final StructuredJsonGenerator jsonGenerator = SdkJsonProtocolFactory
                    .createWriter(false, "1.1");

            jsonGenerator.writeStartObject();

            if (listKeyPoliciesRequest.getKeyId() != null) {
                jsonGenerator.writeFieldName("KeyId").writeValue(
                        listKeyPoliciesRequest.getKeyId());
            }
            if (listKeyPoliciesRequest.getLimit() != null) {
                jsonGenerator.writeFieldName("Limit").writeValue(
                        listKeyPoliciesRequest.getLimit());
            }
            if (listKeyPoliciesRequest.getMarker() != null) {
                jsonGenerator.writeFieldName("Marker").writeValue(
                        listKeyPoliciesRequest.getMarker());
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length",
                    Integer.toString(content.length));
            request.addHeader("Content-Type", jsonGenerator.getContentType());
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}
